Class: Notion::Generated::Endpoints::Oauth
- Inherits:
-
Endpoints::Base
- Object
- Endpoints::Base
- Notion::Generated::Endpoints::Oauth
- Defined in:
- lib/notion/generated/endpoints/oauth.rb
Instance Method Summary collapse
-
#introspect(token:, **params, &block) ⇒ Object
Introspect a token.
-
#revoke(token:, **params, &block) ⇒ Object
Revoke a token.
-
#token(grant_type:, **params, &block) ⇒ Object
Exchange an authorization code for an access and refresh token.
Methods inherited from Endpoints::Base
#initialize, operation, operations
Constructor Details
This class inherits a constructor from Notion::Endpoints::Base
Instance Method Details
#introspect(token:, **params, &block) ⇒ Object
Introspect a token
27 28 29 30 |
# File 'lib/notion/generated/endpoints/oauth.rb', line 27 def introspect(token:, **params, &block) params[:token] = token invoke_operation(:introspect, params, &block) end |
#revoke(token:, **params, &block) ⇒ Object
Revoke a token
21 22 23 24 |
# File 'lib/notion/generated/endpoints/oauth.rb', line 21 def revoke(token:, **params, &block) params[:token] = token invoke_operation(:revoke, params, &block) end |
#token(grant_type:, **params, &block) ⇒ Object
Exchange an authorization code for an access and refresh token
15 16 17 18 |
# File 'lib/notion/generated/endpoints/oauth.rb', line 15 def token(grant_type:, **params, &block) params[:grant_type] = grant_type invoke_operation(:token, params, &block) end |